package com.example.demo.ui.screen.home

import androidx.activity.compose.LocalActivity
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material3.Button
import androidx.compose.material3.FloatingActionButton
import androidx.compose.material3.Icon
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.fragment.app.FragmentActivity
import androidx.hilt.navigation.compose.hiltViewModel
import com.example.demo.component.TextComponent
import com.example.demo.component.TextFieldComponent
import com.example.demo.data.state.HomePageState
import com.example.demo.dialog.AuthRequiredDialog
import com.example.demo.utils.BiometricHelper
import com.example.demo.utils.EncryptionUtil

@Composable
fun HomeScreen(
    modifier: Modifier = Modifier,
    viewmodel: HomeViewmodel = hiltViewModel()
) {

    var text by remember { mutableStateOf("") }
    val state = viewmodel.uiState.value
    val context = LocalActivity.current as FragmentActivity
    var showDialog by remember { mutableStateOf(false) }

    fun openBiometricPrompt() {
        BiometricHelper.showBiometricPrompt(
            activity = context,
            onCancelByUser = {
                showDialog = true
            },
            onAuthResult = {

            })
    }

    LaunchedEffect(Unit) {
        openBiometricPrompt()
    }

    if (showDialog) {
        AuthRequiredDialog(
            onDismissRequest = {
                showDialog = false
            },
            onUsePassword = {
                openBiometricPrompt()
            })
    }

    Scaffold(floatingActionButton = {
        FloatingActionButton(
            onClick = { },
        ) {
            Icon(Icons.Filled.Add, "Floating action button.")
        }
    }) { innerPadding ->
        Column(modifier.padding(innerPadding)) {

            TextFieldComponent(value = text) {
                text = it
            }

            Button(
                onClick = {
                    viewmodel.onEvent(HomePageState.OnSave(text))
                }) {
                TextComponent(
                    text = "Click To Add"
                )
            }

            LazyColumn {
                items(state.listOfCredential) {
                    TextComponent(text = it.id.toString() + " " + EncryptionUtil.decrypt(it.accountType))
                }
            }
        }
    }
}