package com.example.demo.ui.screen.home

import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.demo.data.database.CredentialDatabase
import com.example.demo.data.model.CredentialModel
import com.example.demo.data.state.HomePageState
import com.example.demo.data.state.HomePageUiState
import com.example.demo.utils.EncryptionUtil
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class HomeViewmodel @Inject constructor(private val database: CredentialDatabase) : ViewModel() {

    private val _uiState = mutableStateOf(HomePageUiState())
    val uiState = _uiState

    init {
        viewModelScope.launch {
            database.credentialDao().getAllCredential().collect {
                _uiState.value = uiState.value.copy(it)
            }
        }
    }

    fun onEvent(event: HomePageState) {
        when (event) {
            is HomePageState.OnSave -> {
                viewModelScope.launch {
                    database.credentialDao()
                        .insertCredential(CredentialModel(accountType = EncryptionUtil.encrypt(event.type)))
                }
            }
        }

    }

}