package com.example.demo.utils

import android.util.Log
import androidx.biometric.BiometricPrompt
import androidx.fragment.app.FragmentActivity
import java.util.concurrent.Executor
import java.util.concurrent.Executors

object BiometricHelper {

    fun showBiometricPrompt(
        activity: FragmentActivity,
        onCancelByUser: () -> Unit,
        onAuthResult: (Boolean) -> Unit
    ) {
        val executor: Executor = Executors.newSingleThreadExecutor()

        val promptInfo = BiometricPrompt.PromptInfo.Builder()
            .setTitle("Biometric Authentication")
            .setSubtitle("Authenticate using your fingerprint or face")
//            .setNegativeButtonText("Cancel")
            .setDeviceCredentialAllowed(true)
            .setConfirmationRequired(true)
            .build()

        val biometricPrompt =
            BiometricPrompt(activity, executor, object : BiometricPrompt.AuthenticationCallback() {
                override fun onAuthenticationSucceeded(result: BiometricPrompt.AuthenticationResult) {
                    super.onAuthenticationSucceeded(result)
                    onAuthResult(true)
                }

                override fun onAuthenticationFailed() {
                    super.onAuthenticationFailed()
                    onAuthResult(false)
                }

                override fun onAuthenticationError(errorCode: Int, errString: CharSequence) {
                    super.onAuthenticationError(errorCode, errString)

                    if (errorCode == BiometricPrompt.ERROR_NO_BIOMETRICS) {
                        onAuthResult(true)
                    } else if (errorCode == BiometricPrompt.ERROR_USER_CANCELED) {
                        onCancelByUser.invoke()
                    } else {
                        onAuthResult(false)
                    }
                }
            })

        biometricPrompt.authenticate(promptInfo)
    }
}